taskswitcher/contextengine/tsfswserver/engine/src/tsfswengine.cpp
branchRCL_3
changeset 35 3321d3e205b6
parent 34 5456b4e8b3a8
--- a/taskswitcher/contextengine/tsfswserver/engine/src/tsfswengine.cpp	Wed Sep 01 12:32:46 2010 +0100
+++ b/taskswitcher/contextengine/tsfswserver/engine/src/tsfswengine.cpp	Tue Sep 14 20:58:58 2010 +0300
@@ -364,6 +364,7 @@
 void CTsFswEngine::HiddenAppListUpdated()
     {
     UpdateTaskList();
+    TRAP_IGNORE( iDataList->RemoveHiddenAppsScrenshotsL(); )
     }
 
 // --------------------------------------------------------------------------
@@ -489,10 +490,15 @@
         wgId = aWgId;
         }
     TInt err = iDataList->AppUidForWgId( wgId, appUid );
-    if ( err || appUid == KTsCameraUid )
+    TBool hidden = EFalse;
+    TRAP_IGNORE( 
+    hidden = iDataList->HiddenApps()->IsHiddenL( appUid, iWsSession, aWgId) );
+    if ( err || 
+         KTsCameraUid == appUid ||
+         hidden )
         {
-        // Dont't assign screenshot to camera app
-        TSLOG0( TSLOG_LOCAL, "Screenshot for camera - ignore" );
+        // Dont't assign screenshot to camera app or hidden app
+        TSLOG0( TSLOG_LOCAL, "Screenshot for camera or hidden app - ignore" );
         iPreviewProvider->AckPreview(aFbsHandle);
         TSLOG_OUT();
         return;
@@ -529,11 +535,14 @@
 // Callback from CTsFastSwapPreviewProvider
 // --------------------------------------------------------------------------
 //
-void CTsFswEngine::HandleFswPpApplicationBitmapRotation( TInt aWgId, TBool aClockwise )
+void CTsFswEngine::HandleFswPpApplicationBitmapRotation( TInt aWgId,
+        TInt aFbsHandle, TBool aClockwise )
     {
     TSLOG_CONTEXT( HandleFswPpApplicationBitmapRotation, TSLOG_LOCAL );
     TSLOG1_IN( "aWgId = %d", aWgId );
     
+    HandleFswPpApplicationChange( aWgId, aFbsHandle );
+    
     CFbsBitmap** bmp = iDataList->FindScreenshot(aWgId);
             
     if ( bmp )